@@ -24,6 +24,7 @@ import java.io.PrintStream;
 import java.io.UnsupportedEncodingException;
 import java.net.ServerSocket;
 import java.net.Socket;
+import java.nio.charset.StandardCharsets;
 import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.Enumeration;
@@ -69,7 +70,6 @@ public class SimpleApplication implements Runnable {
             System.err.println("SimpleApplication: arg " + i +
                     " = " + args[i]);
 
-
         }
         if (args.length > 0 && !args[0].isEmpty())
             port=Integer.parseInt(args[0]);
@@ -78,10 +78,10 @@ public class SimpleApplication implements Runnable {
         else
             app.directory="/tmp";
 
-        /* Dump a message */
+        // Dump a message
         System.err.println("SimpleApplication: loading on port "+port);
         Runtime.getRuntime().addShutdownHook(new ShutdownHook(app));
-        /* Set up this simple daemon */
+        // Set up this simple daemon
         app.server = new ServerSocket(port);
         app.thread = new Thread(app);
         app.start();
@@ -89,24 +89,24 @@ public class SimpleApplication implements Runnable {
 
     public void start()
     {
-        /* Dump a message */
+        // Dump a message
         System.err.println("SimpleApplication: starting");
 
-        /* Start */
+        // Start
         this.thread.start();
     }
 
     public void stop()
         throws IOException, InterruptedException
     {
-        /* Dump a message */
+        // Dump a message
         System.err.println("SimpleApplication: stopping");
 
-        /* Close the ServerSocket. This will make our thread to terminate */
+        // Close the ServerSocket. This will make our thread to terminate
         this.stopping=true;
         this.server.close();
 
-        /* Wait for the main thread to exit and dump a message */
+        // Wait for the main thread to exit and dump a message
         this.thread.join(5000);
         System.err.println("SimpleApplication: stopped");
     }
@@ -124,20 +124,20 @@ public class SimpleApplication implements Runnable {
 
         System.err.println("SimpleApplication: started acceptor loop");
         try {
-            while(!this.stopping) {
-                Socket socket=this.server.accept();
-                Handler handler=new Handler(socket,this);
+            while (!this.stopping) {
+                Socket socket = this.server.accept();
+                Handler handler = new Handler(socket, this);
                 handler.setConnectionNumber(number++);
                 handler.setDirectoryName(this.directory);
                 new Thread(handler).start();
             }
         } catch (IOException e) {
-            /* Don't dump any error message if we are stopping. A IOException
-               is generated when the ServerSocket is closed in stop() */
+            // Don't dump any error message if we are stopping. A IOException
+            // is generated when the ServerSocket is closed in stop()
             if (!this.stopping) e.printStackTrace(System.err);
         }
 
-        /* Terminate all handlers that at this point are still open */
+        // Terminate all handlers that at this point are still open
         Enumeration<Handler> openhandlers = this.handlers.elements();
         while (openhandlers.hasMoreElements()) {
             Handler handler = openhandlers.nextElement();
@@ -198,18 +198,16 @@ public class SimpleApplication implements Runnable {
         @Override
         public void run() {
             this.parent.addHandler(this);
-            System.err.println("SimpleApplication: connection "+this.number+
-                               " opened from "+this.socket.getInetAddress());
+            System.err.println("SimpleApplication: connection " + this.number + " opened from " + this.socket.getInetAddress());
             try {
-                InputStream in=this.socket.getInputStream();
-                OutputStream out=this.socket.getOutputStream();
-                handle(in,out);
+                InputStream in = this.socket.getInputStream();
+                OutputStream out = this.socket.getOutputStream();
+                handle(in, out);
                 this.socket.close();
             } catch (IOException e) {
                 e.printStackTrace(System.err);
             }
-            System.err.println("SimpleApplication: connection "+this.number+
-                               " closed");
+            System.err.println("SimpleApplication: connection " + this.number + " closed");
             this.parent.removeHandler(this);
         }
 
@@ -237,11 +235,10 @@ public class SimpleApplication implements Runnable {
             return(this.directory);
         }
 
-        public void createFile(String name)
-        throws IOException {
-            OutputStream file=new FileOutputStream(name,true);
-            PrintStream out=new PrintStream(file);
-            SimpleDateFormat fmt=new SimpleDateFormat();
+        public void createFile(String name) throws IOException {
+            OutputStream file = new FileOutputStream(name, true);
+            PrintStream out = new PrintStream(file);
+            SimpleDateFormat fmt = new SimpleDateFormat();
 
             out.println(fmt.format(new Date()));
             out.close();
@@ -252,24 +249,24 @@ public class SimpleApplication implements Runnable {
         throws IOException {
             File file = new File(name);
             boolean ok = file.mkdirs();
-            if(! ok)
+            if (!ok)
                 throw new IOException("mkdirs for "+name+" failed");
             createFile(name);
         }
 
         public void handle(InputStream in, OutputStream os) {
-            PrintStream out=null;
+            PrintStream out = null;
             try {
-                out=new PrintStream(os, true, "US-ASCII");
+                out = new PrintStream(os, true, StandardCharsets.US_ASCII.name());
             } catch (UnsupportedEncodingException ex) {
-              out=new PrintStream(os, true);
+                out = new PrintStream(os, true);
             }
 
-            while(true) {
+            while (true) {
                 try {
-                    /* If we don't have data in the System InputStream, we want
-                       to ask to the user for an option. */
-                    if (in.available()==0) {
+                    // If we don't have data in the System InputStream, we want
+                    // to ask to the user for an option.
+                    if (in.available() == 0) {
                         out.println();
                         out.println("Please select one of the following:");
                         out.println("    1) Shutdown");
@@ -280,84 +277,74 @@ public class SimpleApplication implements Runnable {
                         out.print("Your choice: ");
                     }
 
-                    /* Read an option from the client */
-                    int x=in.read();
+                    // Read an option from the client
+                    int x = in.read();
 
                     switch (x) {
-                        /* If the socket was closed, we simply return */
-                        case -1:
-                            return;
+                    // If the socket was closed, we simply return
+                    case -1:
+                        return;
 
-                        /* Attempt to shutdown */
-                        case '1':
-                            out.println("Attempting a shutdown...");
-                            try {
-                                System.exit(0);
-                            } catch (IllegalStateException e) {
-                                out.println();
-                                out.println("Can't shutdown now");
-                                e.printStackTrace(out);
-                            }
-                            break;
+                    // Attempt to shutdown
+                    case '1':
+                        out.println("Attempting a shutdown...");
+                        try {
+                            System.exit(0);
+                        } catch (IllegalStateException e) {
+                            out.println();
+                            out.println("Can't shutdown now");
+                            e.printStackTrace(out);
+                        }
+                        break;
 
-                        /* Create a file */
-                        case '2':
-                            String name=this.getDirectoryName()+
-                                        "/SimpleApplication."+
-                                        this.getConnectionNumber()+
-                                        ".tmp";
-                            try {
-                                this.createFile(name);
-                                out.println("File '"+name+"' created");
-                            } catch (IOException e) {
-                                e.printStackTrace(out);
-                            }
-                            break;
+                    // Create a file
+                    case '2':
+                        String name = this.getDirectoryName() + "/SimpleApplication." + this.getConnectionNumber() + ".tmp";
+                        try {
+                            this.createFile(name);
+                            out.println("File '" + name + "' created");
+                        } catch (IOException e) {
+                            e.printStackTrace(out);
+                        }
+                        break;
 
-                        /* Disconnect */
-                        case '3':
-                            out.println("Disconnecting...");
-                            return;
+                    // Disconnect
+                    case '3':
+                        out.println("Disconnecting...");
+                        return;
 
-                        /* Crash JVM in a native call: It need an so file ;-) */
-                        case '4':
-                            System.load(System.getProperty("native.library", "./Native.so"));
-                            toto();
-                            break;
+                    // Crash JVM in a native call: It need an so file ;-)
+                    case '4':
+                        System.load(System.getProperty("native.library", "./Native.so"));
+                        toto();
+                        break;
 
-                        /* Create a directory (PR 30177 with 1.4.x and 1.5.0 */
-                        case '5':
-                            String name1=this.getDirectoryName()+
-                                        "/a/b/c/d/e"+
-                                        "/SimpleApplication."+
-                                        this.getConnectionNumber()+
-                                        ".tmp";
-                            try {
-                                this.createDir(name1);
-                                out.println("File '"+name1+"' created");
-                            } catch (IOException e) {
-                                e.printStackTrace(out);
-                            }
-                            break;
+                    // Create a directory (PR 30177 with 1.4.x and 1.5.0
+                    case '5':
+                        String name1 = this.getDirectoryName() + "/a/b/c/d/e" + "/SimpleApplication." + this.getConnectionNumber() + ".tmp";
+                        try {
+                            this.createDir(name1);
+                            out.println("File '" + name1 + "' created");
+                        } catch (IOException e) {
+                            e.printStackTrace(out);
+                        }
+                        break;
 
+                    // Discard any carriage return / newline characters
+                    case '\r':
+                    case '\n':
+                        break;
 
-                        /* Discard any carriage return / newline characters */
-                        case '\r':
-                        case '\n':
-                            break;
-
-                        /* We got something that we weren't supposed to get */
-                        default:
-                            out.println("Unknown option '"+(char)x+"'");
-                            break;
+                    // We got something that we weren't supposed to get
+                    default:
+                        out.println("Unknown option '" + (char) x + "'");
+                        break;
 
                     }
 
-                /* If we get an IOException we return (disconnect) */
+                    // If we get an IOException we return (disconnect)
                 } catch (IOException e) {
-                    System.err.println("SimpleApplication: IOException in "+
-                                       "connection "+
-                                       this.getConnectionNumber());
+                    System.err.println("SimpleApplication: IOException in " + "connection " + this.getConnectionNumber());
                     return;
                 }
             }
